@@ -24,6 +24,9 @@ use NewsExtractor::SiteSpecificExtractor::turnnewsapp_com;
 use NewsExtractor::SiteSpecificExtractor::news_cts_com_tw;
 use NewsExtractor::SiteSpecificExtractor::estate_ltn_com_tw;
 use NewsExtractor::SiteSpecificExtractor::www_upmedia_mg;
+use NewsExtractor::SiteSpecificExtractor::ctee_com_tw;
+use NewsExtractor::SiteSpecificExtractor::news_ebc_net_tw;
+use NewsExtractor::SiteSpecificExtractor::newnet_tw;
 use NewsExtractor::SiteSpecificExtractor::UDN;
 use NewsExtractor::SiteSpecificExtractor::ETtoday;
 use NewsExtractor::SiteSpecificExtractor::ChinaTimes;
@@ -66,6 +69,9 @@ use constant {
         'news.cts.com.tw' => 'NewsExtractor::SiteSpecificExtractor::news_cts_com_tw',
         'estate.ltn.com.tw' => 'NewsExtractor::SiteSpecificExtractor::estate_ltn_com_tw',
         'www.upmedia.mg' => 'NewsExtractor::SiteSpecificExtractor::www_upmedia_mg',
+        'ctee.com.tw' => 'NewsExtractor::SiteSpecificExtractor::ctee_com_tw',
+        'news.ebc.net.tw' => 'NewsExtractor::SiteSpecificExtractor::news_ebc_net_tw',
+        'newnet.tw' => 'NewsExtractor::SiteSpecificExtractor::newnet_tw',
     },
     CSSRuleSetByHost => {
         'www.taiwannews.com.tw' => {
