@@ -167,8 +167,6 @@ sub journalist {
         ($ret) = $guess->all_text =~ m{\A 【 (記者 .+) 】}x;
     } elsif ($guess = $dom->at('#details_block .left .name, .articleMain .article-author a.author-title, .article__credit a[href^="/author/"], span[itemprop=author] span[itemprop=name], .post-header-additional .post-meta-info a.nickname')) {
         $ret = $guess->text;
-    } elsif ($guess = $dom->at('.fncnews-content > .info > span.small-gray-text')) {
-        ($ret) = $guess->text =~ m<(責任編輯.+)\z>x;
     } elsif ($guess = $dom->at('div.single-post-meta a[rel="author"]')) {
         ($ret) = $guess->text =~ m<^工商時報 (.+)\z>x;
     }
@@ -181,7 +179,8 @@ sub journalist {
             qr<\A 【(記者.+?報導)】>x,
             qr<\A 中評社 .+? \d+ 月 \d+ 日電（記者(.+?)）>x,
             qr<\A ( 記者[^／]+／.+?電 )>x,
-            qr<\A 匯流新聞網記者 (\p{Letter}+) ／綜合報導 >x,
+            qr<\A 匯流新聞網記者 (\p{Letter}+) ／(?:\p{Letter}+)報導 >x,
+            qr<\A 匯流新聞網記者\s*/\s*(\p{Letter}+)綜合報導>x,
             qr<（(中央社[记記]者 \S+ 日 專?[電电] | 大纪元记者\p{Letter}+报导 | 記者.+?報導/.+?)）>x,
             qr< \( ( \p{Letter}+ ／ \p{Letter}+ 報導 ) \) >x,
             qr<\A 文：記者(\p{Letter}+) \n>x,
@@ -199,6 +198,7 @@ sub journalist {
             qr<\A  （ (記者.+報導) ） >x,
             qr<\A 【(本報記者.+報導)】 >x,
             qr<\b ﹝記者(\p{Letter}+?)／.+?報導﹞ \b>x,
+            qr<\A〔新網記者 ( \p{Letter}+ (?:報導|特稿))〕\b>x,
         );
 
         for my $pat (@patterns) {
